LayerContainerXml
=================

.. currentmodule:: wwt_data_formats.layers

.. autoclass:: LayerContainerXml
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LayerContainerXml.id
      ~LayerContainerXml.layers

   .. rubric:: Attributes Documentation

   .. autoattribute:: id
   .. autoattribute:: layers
